@@ -10,10 +10,10 @@ if (-t and not @ARGV) {
     exit;
 }
 
-our ($data, $result);
-
 our $data = do {local $/; <>};
 
+our $result;
+
 cmpthese(-10, {
     Bencode_XS  =>  sub {$result = Convert::Bencode_XS::bdecode($data)},
     Bencode     =>  sub {$result = Convert::Bencode::bdecode($data)},
